@@ -5,7 +5,7 @@ require Exporter;
 use 5.00600;
 use utf8;
 use vars qw($DefaultClass %EXPORT_TAGS @EXPORT_OK @ISA %anker @TreeView %openArrays @caption $columns $clasic $ffirst $sort $border $orderby $size $style $orderbyColumn $prefix $bTrOver $desc %anker %ankerG $lang);
-$HTML::Menu::TreeView::VERSION = '1.12';
+$HTML::Menu::TreeView::VERSION = '1.15';
 @ISA                           = qw(Exporter);
 @HTML::Menu::TreeView::EXPORT_OK =
   qw(border Tree css columns jscript setStyle setDocumentRoot getDocumentRoot setSize setClasic clasic preload help folderFirst size style Style documentRoot loadTree saveTree  %anker %ankerG sortTree orderBy orderByColumn prefix setModern border TrOver desc language);
@@ -18,7 +18,7 @@ $HTML::Menu::TreeView::VERSION = '1.12';
 );
 $DefaultClass = 'HTML::Menu::TreeView' unless defined $HTML::Menu::TreeView::DefaultClass;
 our $id       = 'a';
-our $path     = '%PATH%';
+our $path     = '/var/www/htdocs';
 our $saveFile = './TreeViewDump.pl';
 $lang  = 'en';
 $style = 'Crystal';
@@ -109,7 +109,7 @@ HTML::Menu::TreeView - Create a HTML TreeView from scratch
 
           text => 'treeview Homepage',
 
-          href => 'http://treeview.lindnerei.de'
+          href => 'http://lindnerei.sourceforge.net'
 
           }
 
@@ -188,11 +188,17 @@ HTML::Menu::TreeView is a Modul to build an Html TreeView.
 
 =head1 Changes
 
+1.14
+    after a few years there a only a few bugfixes.
+
+1.13
+
+Sorting of closed folders will work now.
+
 1.12
 
 some fixes (German umlaute help())
 
-
 1.10
 
 Overwrought
@@ -441,14 +447,14 @@ sub Tree
         $r .= "//-->\n</script>";
     }
     $r .=
-qq(<table border="0" cellpadding="0" cellspacing="0" summary="Tree"><tr><td><table cellpadding="0" cellspacing="0"  align="left" border="0" summary="Tree" width="100%" class="treeview$size"><colgroup><col width="$size"/></colgroup>);
+qq(<table border="0" cellpadding="0" cellspacing="0" summary="Tree" width="100%"><tr><td class="subtree"><table cellpadding="0" cellspacing="0"  align="left" border="0" summary="Tree" width="100%" class="treeview$size"><colgroup><col width="$size"/></colgroup>);
     if (defined @caption) {
         my $class = $border ? "captionBorder$size" : "caption$size";
         $r .= qq(<tr><td class="$class"></td><td class="$class">$caption[0]</td></tr>);
     }
     $r .= $self->{tree} . '</table></td>';
     if (defined $self->{subtree}) {
-        $r .= '<td><table align="left" border="0" cellpadding="0" cellspacing="0" summary="subTree" width="100%" >';
+        $r .= '<td class="subtree"><table align="left" border="0" cellpadding="0" cellspacing="0" summary="subTree" width="100%">';
         if (defined @caption) {
             my $class = $border ? "captionBorder$size" : "caption$size";
             $r .= '<tr>';
@@ -931,7 +937,7 @@ folderTar,folderYellow ,folderGray,
 
 folderGreen and folderRed
 
-see http://treeview.lindnerei.de/cgi-bin/crystal.pl for a complete list of possible values for folderclass.
+see http://lindnerei.sourceforge.net/cgi-bin/crystal.pl for a complete list of possible values for folderclass.
 
 =item columns
 
@@ -1130,7 +1136,7 @@ sub initTree
         next if ref @$tree[$i] ne "HASH";
         $length--;
         if (defined @$tree[$i]) {
-            if (defined @{@$tree[$i]->{subtree}}) {
+             if (defined @{@$tree[$i]->{subtree}} && not defined @$tree[$i]->{empty}) {#a smalll fix, sorting closed folders will work with this change.
                 if ($length > 0) {
                     $self->appendFolder(@$tree[$i], \@{@$tree[$i]->{subtree}});
                 } elsif ($length eq 0) {
@@ -1225,14 +1231,11 @@ sub appendFolder
     $node->{onclick} =
         defined $node->{onclick} ? $node->{onclick}
       : defined $node->{href}    ? ''
-      :                            qq(ocFolder('$id');displayTree('$id');hideArray('$id');ocNode('$id.node','$size'););
-    my $onclick = qq(ocFolder('$id');displayTree('$id');hideArray('$id');ocNode('$id.node','$size'););
-    $node->{class} = defined $node->{class} ? $node->{class} : "treeviewLink$size";
-    my $FolderClass =
-      defined $node->{folderclass}
-      ? $node->{folderclass} . $size
-      : "folder$size";
-    $node->{title} = defined $node->{title} ? $node->{title} : $node->{text};
+      : qq(ocFolder('$id');displayTree('$id');hideArray('$id');ocNode('$id.node','$size'););
+    my $onclick = qq( ocFolder('$id');displayTree('$id');hideArray('$id');ocNode('$id.node','$size'););
+    $node->{class}  = defined $node->{class} ? $node->{class} : "treeviewLink$size";
+    my $FolderClass = defined $node->{folderclass} ? $node->{folderclass} . $size : "folder$size";
+    $node->{title}  = defined $node->{title} ? $node->{title} : $node->{text};
     my $tt;
     foreach my $key (keys %{$node}) {
         $tt .= $key . '="' . $node->{$key} . '" ' if ($anker{$key} && $node->{$key});
@@ -1243,12 +1246,8 @@ sub appendFolder
       ? qq(<table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendFolder" width="100%"><tr><td $st>&#160;<a $tt>$node->{text}</a>&#160;</td><td $st>$node->{addition}</td></tr></table>)
       : "&#160;<a $tt >$node->{text}</a>&#160;";
     my $minusnode = $clasic ? "clasicMinusNode$size" : "minusNode$size";
-    $self->{tree} .= (
-                      $bTrOver
-                      ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">)
-                      : '<tr>'
-      )
-      . qq(<td id="$id.node" class="$minusnode"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td align="left" class="$FolderClass" id="$id.folder" ><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td $st align="left">$addon</td></tr></table></td></tr><tr id="$id"><td class="submenuDeco$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" alt=""/></td><td><table align="left" border="0" cellpadding="0" cellspacing="0"   summary="appendFolder" width="100%"><colgroup><col width="$size"/></colgroup>);
+    $self->{tree} .= ( $bTrOver ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">) : '<tr>' )
+      . qq(<td id="$id.node" class="$minusnode"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td align="left" class="$FolderClass" id="$id.folder" ><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" onclick="$onclick"/></td><td $st align="left">$addon</td></tr></table></td></tr><tr id="$id"><td class="submenuDeco$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" alt=""/></td><td class="subtree"><table align="left" border="0" cellpadding="0" cellspacing="0"   summary="appendFolder" width="100%"><colgroup><col width="$size"/></colgroup>);
 
     if ($columns > 0) {
         my $class = $border ? "columnsFolderBorder$size" : "columnsFolder$size";
@@ -1266,8 +1265,10 @@ sub appendFolder
         $self->{subtree} .= '</tr>';
     }
     $self->initTree(\@$subtree);
-    if ($columns > 0) {
-        for (my $i = 0; $i < @$tmpref; $i++) {
+    if ($columns > 0)
+    {
+        for (my $i = 0; $i < @$tmpref; $i++)
+        {
             $self->{js}{$ty}[$i] = $$tmpref[$i];
         }
         undef @$tmpref;
@@ -1324,7 +1325,7 @@ sub appendLastFolder
                       ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">)
                       : '<tr>'
       )
-      . qq(<td id="$id.node" class="$lastminusnode" onclick="$onclick"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" /></td><td align="left" class="$FolderClass" id="$id.folder"><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendLastFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" alt="" onclick="$onclick"/></td><td $st align="left">$addon</td></tr></table></td></tr><tr id="$id"><td><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt=""/></td><td><table align="left" width="100%" cellpadding="0" cellspacing="0" border="0" summary="appendLastFolder"><colgroup><col width="$size"/></colgroup>);
+      . qq(<td id="$id.node" class="$lastminusnode" onclick="$onclick"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" /></td><td align="left" class="$FolderClass" id="$id.folder"><table align="left" border="0" cellpadding="0" cellspacing="0" summary="appendLastFolder" width="100%"><tr><td $st valign="top" width="$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" alt="" onclick="$onclick"/></td><td $st align="left">$addon</td></tr></table></td></tr><tr id="$id"><td class="subtree"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt=""/></td><td class="subtree"><table align="left" width="100%" cellpadding="0" cellspacing="0" border="0" summary="appendLastFolder"><colgroup><col width="$size"/></colgroup>);
 
     if ($columns > 0) {
         my $class = $border ? "columnsFolderBorder$size" : "columnsFolder$size";
@@ -1518,7 +1519,7 @@ sub appendNode
                       ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">)
                       : '<tr>'
       )
-      . qq(<td class="node$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" align="middle"/></td><td align="left"  style="background-image:url('$prefix/style/$style/$size/mimetypes/$node->{image}');background-repeat:no-repeat;cursor:pointer;padding-left:$paddingLeft">$addon</td></tr>);
+      . qq(<td class="node$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt="" align="middle"/></td><td align="left"  style="background-image:url('$prefix/style/$style/$size/mimetypes/$node->{image}');background-repeat:no-repeat;cursor:pointer;background-position:0px 5px;;padding-left:$paddingLeft">$addon</td></tr>);
     if ($columns > 0) {
         $self->{subtree} .= (
                              $bTrOver
@@ -1572,7 +1573,7 @@ sub appendLastNode
                       ? qq(<tr onmouseover = "trOver('$id');" onmouseout="trUnder('$id');" id="tree$id">)
                       : '<tr>'
       )
-      . qq(<td class="lastNode$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt=""/></td><td align="left"  style="background-image:url('$prefix/style/$style/$size/mimetypes/$node->{image}');background-repeat:no-repeat;cursor:pointer;padding-left:$paddingLeft;">$addon</td></tr>);
+      . qq(<td class="lastNode$size"><img src="$prefix/style/$style/$size/html-menu-treeview/spacer.gif" border="0" width="$size" height="$size" alt=""/></td><td align="left"  style="background-image:url('$prefix/style/$style/$size/mimetypes/$node->{image}');background-repeat:no-repeat;cursor:pointer;background-position:0px 5px;;padding-left:$paddingLeft;">$addon</td></tr>);
     if ($columns > 0) {
         my $class = $border ? "columnsLastNodeBorder$size" : "columnsLastNode$size";
         $self->{subtree} .= (
@@ -1592,17 +1593,17 @@ sub appendLastNode
 
 =head1 SEE ALSO
 
-http://treeview.lindnerei.de, http://lindnerei.svn.sourceforge.net/viewvc/lindnerei/treeview/
+http://lindnerei.sourceforge.net
 
 =head1 AUTHOR
 
-Dirk Lindner <lze@cpan.org>
+Dirk Lindner <dirk.lze@gmail.com>
 
 =head1 LICENSE
 
 LGPL
 
-Copyright (C) 2009 by Hr. Dirk Lindner
+Copyright (C) 2015 by Hr. Dirk Lindner
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public License
